@@ -22,19 +22,19 @@ BEGIN {
 
 =head1 NAME
 
-Data::Consumer::MySQL - Data::Consumer implementation for a mysql database table resource
+Data::Consumer::MySQL - DEPRECATED Data::Consumer implementation for a mysql database table resource
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
-$VERSION= '0.14';
+$VERSION= '0.15';
 
 =head1 SYNOPSIS
 
-    use Data::Consumer::MySQL;
+    use Data::Consumer::MySQL; # deprecated, use Data::Consumer::MySQL2 instead!
 
     my $consumer = Data::Consumer::MySQL->new(
         dbh => $dbh,
@@ -53,6 +53,10 @@ $VERSION= '0.14';
         print "processed $id\n";
     } );
 
+=head1 DEPRECATED MODULE
+
+This module is deprecated in favour of L<Data::Consumer::MySQL2>, you are strongly
+advised to migrate to the new module.
 
 =head1 FUNCTIONS
 
@@ -190,6 +194,10 @@ sub new {
     my ( $class, %opts )= @_;
     my $self= $class->SUPER::new();    # let Data::Consumer bless the hash
 
+    unless ($opts{no_deprecated_warnings_please}) {
+        warn "$class is deprecated, you are strongly encouraged to migrate to Data::Consumer::MySQL2";
+    }
+
     if ( !$opts{dbh} and $opts{connect} ) {
         $opts{dbh}= DBI->connect( @{ $opts{connect} } )
           or confess
